pyLBM.stencil.OneStencil
========================

.. currentmodule:: pyLBM.stencil

.. autoclass:: OneStencil

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         OneStencil.num
         OneStencil.vx
         OneStencil.vy
         OneStencil.vz

